An example dataset
Format
Visium_human_DLPFC
A list with 3 elements
- counts
Gene expression count matrix. Rows and columns indicate genes and spots, respectively.
- spatial_coords
Spatial coordinates matrix. Rows indicate spots.
- cell_type_proportions
Cell type proportion matrix estimated by RCTD. Rows and columns indicate spots and cell types, respectively.
The Visium_human_DLPFC dataset contains Visium human dorsolateral prefrontal cortex (DLPFC) dataset (ID: 151673) which is available at https://research.libd.org/spatialLIBD/.